import { PizzaOrder } from "./Types";
import { getBaseUrl } from "./Utils";

async function request<TResponse>(
    url: string,
    config: RequestInit = {}
): Promise<TResponse> {
    return fetch(getBaseUrl() + url, config).then(response => {
        if (!response.ok) {
            throw new Error(response.statusText);
        }
        return response.json() as TResponse;
    });
}

const api = {
    get: <TResponse>(url: string) => request<TResponse>(url),
    post: <TBody extends BodyInit, TResponse>(url: string, body: TBody) => request<TResponse>(url, { method: 'POST', body, headers: { 'Content-Type': 'application/json' } }),
}

export const getQrUrl = (login: string) => {
    return `${getBaseUrl()}/api/qr?login=${login}`;
}

export const getData = async () => {
    return await api.get<any>('/api/data');
}

export const getFood = async () => {
    return await api.get<any>('/api/food');
}

export const getPizzy = async () => {
    return await api.get<any>('/api/pizza');
}

export const createPizzaDay = async (creator) => {
    return await api.post<any, any>('/api/createPizzaDay', JSON.stringify({ creator }));
}

export const deletePizzaDay = async (login) => {
    return await api.post<any, any>('/api/deletePizzaDay', JSON.stringify({ login }));
}

export const lockPizzaDay = async (login) => {
    return await api.post<any, any>('/api/lockPizzaDay', JSON.stringify({ login }));
}

export const unlockPizzaDay = async (login) => {
    return await api.post<any, any>('/api/unlockPizzaDay', JSON.stringify({ login }));
}

export const finishOrder = async (login) => {
    return await api.post<any, any>('/api/finishOrder', JSON.stringify({ login }));
}

export const finishDelivery = async (login, bankAccount, bankAccountHolder) => {
    return await api.post<any, any>('/api/finishDelivery', JSON.stringify({ login, bankAccount, bankAccountHolder }));
}

export const updateChoice = async (name: string, choice: number | null) => {
    return await api.post<any, any>('/api/updateChoice', JSON.stringify({ name, choice }));
}

export const addPizza = async (login: string, pizzaIndex: number, pizzaSizeIndex: number) => {
    return await api.post<any, any>('/api/addPizza', JSON.stringify({ login, pizzaIndex, pizzaSizeIndex }));
}

export const removePizza = async (login: string, pizzaOrder: PizzaOrder) => {
    return await api.post<any, any>('/api/removePizza', JSON.stringify({ login, pizzaOrder }));
}

export const updateNote = async (login: string, note?: string) => {
    return await api.post<any, any>('/api/updateNote', JSON.stringify({ login, note }));
}